@@ -14,7 +14,7 @@ Version 0.01
 
 =cut
 
-our $VERSION = '0.1201';
+our $VERSION = '0.1202';
 
 use parent 'Games::Solitaire::Verify::Base';
 
@@ -243,7 +243,7 @@ sub num_empty
 
 =head1 AUTHOR
 
-Shlomi Fish, C<< <shlomif at iglu.org.il> >>
+Shlomi Fish, L<http://www.shlomifish.org/>.
 
 =head1 BUGS
 
