@@ -15,7 +15,7 @@ Version 0.1001
 
 =cut
 
-our $VERSION = '0.1201';
+our $VERSION = '0.1202';
 
 use parent 'Games::Solitaire::Verify::Base';
 
@@ -538,7 +538,7 @@ sub verify
 
 =head1 AUTHOR
 
-Shlomi Fish, C<< <shlomif at iglu.org.il> >>
+Shlomi Fish, L<http://www.shlomifish.org/>.
 
 =head1 BUGS
 
