@@ -18,7 +18,7 @@ Version 0.03
 
 =cut
 
-our $VERSION = '0.1201';
+our $VERSION = '0.1202';
 
 sub _init
 {
@@ -293,7 +293,7 @@ L<Games::Solitaire::Verify::VariantParams> .
 
 =head1 AUTHOR
 
-Shlomi Fish, C<< <shlomif at iglu.org.il> >>
+Shlomi Fish, L<http://www.shlomifish.org/>.
 
 =head1 BUGS
 
